[Libreoffice-commits] core.git: shell/source

Noel Grandin noel at peralex.com
Thu Oct 29 08:44:34 UTC 2015


 shell/source/backends/kde4be/kde4access.hxx           |    3 
 shell/source/backends/kdebe/kdeaccess.hxx             |    3 
 shell/source/backends/wininetbe/wininetbackend.hxx    |   16 +--
 shell/source/cmdmail/cmdmailmsg.cxx                   |    2 
 shell/source/cmdmail/cmdmailmsg.hxx                   |   76 +++++++++---------
 shell/source/cmdmail/cmdmailsuppl.cxx                 |   10 +-
 shell/source/cmdmail/cmdmailsuppl.hxx                 |   30 +++----
 shell/source/sessioninstall/SyncDbusSessionHelper.hxx |   30 +++----
 shell/source/unix/exec/shellexec.cxx                  |   10 --
 shell/source/unix/exec/shellexec.hxx                  |   19 ++--
 shell/source/win32/SysShExec.hxx                      |   19 ++--
 shell/source/win32/simplemail/smplmailclient.cxx      |    2 
 shell/source/win32/simplemail/smplmailmsg.hxx         |   57 ++++++-------
 shell/source/win32/simplemail/smplmailsuppl.hxx       |   16 +--
 14 files changed, 143 insertions(+), 150 deletions(-)

New commits:
commit 56c4032272bc70086e61cc10009956966d6b0e8a
Author: Noel Grandin <noel at peralex.com>
Date:   Thu Oct 29 10:10:35 2015 +0200

    com::sun::star->css in shell
    
    Change-Id: Id74a5e79764f37944afab4d2a0dcfc7dbfc9b295
    Reviewed-on: https://gerrit.libreoffice.org/19663
    Reviewed-by: Noel Grandin <noelgrandin at gmail.com>
    Tested-by: Noel Grandin <noelgrandin at gmail.com>

diff --git a/shell/source/backends/kde4be/kde4access.hxx b/shell/source/backends/kde4be/kde4access.hxx
index 004a9c9..7d63c4a 100644
--- a/shell/source/backends/kde4be/kde4access.hxx
+++ b/shell/source/backends/kde4be/kde4access.hxx
@@ -30,8 +30,7 @@ namespace com { namespace sun { namespace star { namespace uno {
 
 namespace kde4access {
 
-com::sun::star::beans::Optional< com::sun::star::uno::Any > getValue(
-    OUString const & id);
+css::beans::Optional< css::uno::Any > getValue(OUString const & id);
 
 }
 
diff --git a/shell/source/backends/kdebe/kdeaccess.hxx b/shell/source/backends/kdebe/kdeaccess.hxx
index 2e4cba9..223da8c 100644
--- a/shell/source/backends/kdebe/kdeaccess.hxx
+++ b/shell/source/backends/kdebe/kdeaccess.hxx
@@ -31,8 +31,7 @@ namespace rtl { class OUString; }
 
 namespace kdeaccess {
 
-com::sun::star::beans::Optional< com::sun::star::uno::Any > getValue(
-    OUString const & id);
+css::beans::Optional< css::uno::Any > getValue(OUString const & id);
 
 }
 
diff --git a/shell/source/backends/wininetbe/wininetbackend.hxx b/shell/source/backends/wininetbe/wininetbackend.hxx
index d6913a4..8109874 100644
--- a/shell/source/backends/wininetbe/wininetbackend.hxx
+++ b/shell/source/backends/wininetbe/wininetbackend.hxx
@@ -126,21 +126,21 @@ class WinInetBackend : public ::cppu::WeakImplHelper <
         ~WinInetBackend() ;
 
     private:
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueProxyType_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueNoProxy_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueHttpProxyName_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueHttpProxyPort_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueHttpsProxyName_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueHttpsProxyPort_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueFtpProxyName_;
-        com::sun::star::beans::Optional< com::sun::star::uno::Any >
+        css::beans::Optional< css::uno::Any >
             valueFtpProxyPort_;
 } ;
 
diff --git a/shell/source/cmdmail/cmdmailmsg.cxx b/shell/source/cmdmail/cmdmailmsg.cxx
index 287a735..5fd0da3 100644
--- a/shell/source/cmdmail/cmdmailmsg.cxx
+++ b/shell/source/cmdmail/cmdmailmsg.cxx
@@ -158,7 +158,7 @@ Any SAL_CALL CmdMailMsg::getByName( const OUString& aName )
 }
 
 Sequence< OUString > SAL_CALL CmdMailMsg::getElementNames(  )
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    throw (css::uno::RuntimeException, std::exception)
 {
     MutexGuard aGuard( m_aMutex );
 
diff --git a/shell/source/cmdmail/cmdmailmsg.hxx b/shell/source/cmdmail/cmdmailmsg.hxx
index cc096a3..4f3a824 100644
--- a/shell/source/cmdmail/cmdmailmsg.hxx
+++ b/shell/source/cmdmail/cmdmailmsg.hxx
@@ -34,18 +34,18 @@
 
 class CmdMailMsg :
     public  cppu::WeakImplHelper<
-        ::com::sun::star::system::XSimpleMailMessage2,
-        ::com::sun::star::container::XNameAccess >
+        css::system::XSimpleMailMessage2,
+        css::container::XNameAccess >
 {
-    OUString                                   m_aBody;
-    OUString                                   m_aRecipient;
-    OUString                                   m_aOriginator;
-    OUString                                   m_aSubject;
-    ::com::sun::star::uno::Sequence< OUString >  m_CcRecipients;
-    ::com::sun::star::uno::Sequence< OUString >  m_BccRecipients;
-    ::com::sun::star::uno::Sequence< OUString >  m_Attachments;
+    OUString                        m_aBody;
+    OUString                        m_aRecipient;
+    OUString                        m_aOriginator;
+    OUString                        m_aSubject;
+    css::uno::Sequence< OUString >  m_CcRecipients;
+    css::uno::Sequence< OUString >  m_BccRecipients;
+    css::uno::Sequence< OUString >  m_Attachments;
 
-    ::osl::Mutex m_aMutex;
+    ::osl::Mutex                    m_aMutex;
 
 public:
 
@@ -56,69 +56,69 @@ public:
 
 
     virtual void SAL_CALL setBody( const OUString& aBody )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual OUString SAL_CALL getBody(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual void SAL_CALL setRecipient( const OUString& aRecipient )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual OUString SAL_CALL getRecipient(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
-    virtual void SAL_CALL setCcRecipient( const ::com::sun::star::uno::Sequence< OUString >& aCcRecipient )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL setCcRecipient( const css::uno::Sequence< OUString >& aCcRecipient )
+        throw (css::uno::RuntimeException, std::exception) override;
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getCcRecipient(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getCcRecipient(  )
+        throw (css::uno::RuntimeException, std::exception) override;
 
-    virtual void SAL_CALL setBccRecipient( const ::com::sun::star::uno::Sequence< OUString >& aBccRecipient )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL setBccRecipient( const css::uno::Sequence< OUString >& aBccRecipient )
+        throw (css::uno::RuntimeException, std::exception) override;
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getBccRecipient(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getBccRecipient(  )
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual void SAL_CALL setOriginator( const OUString& aOriginator )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual OUString SAL_CALL getOriginator(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual void SAL_CALL setSubject( const OUString& aSubject )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual OUString SAL_CALL getSubject(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
-    virtual void SAL_CALL setAttachement( const ::com::sun::star::uno::Sequence< OUString >& aAttachement )
-        throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL setAttachement( const css::uno::Sequence< OUString >& aAttachement )
+        throw (css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception) override;
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getAttachement(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getAttachement(  )
+        throw (css::uno::RuntimeException, std::exception) override;
 
 
     // XNameAccess
 
 
-    virtual ::com::sun::star::uno::Any SAL_CALL getByName( const OUString& aName )
-        throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Any SAL_CALL getByName( const OUString& aName )
+        throw (css::container::NoSuchElementException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getElementNames(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override ;
+    virtual css::uno::Sequence< OUString > SAL_CALL getElementNames(  )
+        throw (css::uno::RuntimeException, std::exception) override ;
 
     virtual sal_Bool SAL_CALL hasByName( const OUString& aName )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
 
     // XElementAccess
 
 
-    virtual ::com::sun::star::uno::Type SAL_CALL getElementType(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Type SAL_CALL getElementType(  )
+        throw (css::uno::RuntimeException, std::exception) override;
 
     virtual sal_Bool SAL_CALL hasElements(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::uno::RuntimeException, std::exception) override;
 
 };
 
diff --git a/shell/source/cmdmail/cmdmailsuppl.cxx b/shell/source/cmdmail/cmdmailsuppl.cxx
index 4ee28ea..8d6a35b 100644
--- a/shell/source/cmdmail/cmdmailsuppl.cxx
+++ b/shell/source/cmdmail/cmdmailsuppl.cxx
@@ -94,7 +94,7 @@ Reference< XSimpleMailClient > SAL_CALL CmdMailSuppl::querySimpleMailClient(  )
 
 
 Reference< XSimpleMailMessage > SAL_CALL CmdMailSuppl::createSimpleMailMessage(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception)
+        throw (css::uno::RuntimeException, std::exception)
 {
     return Reference< XSimpleMailMessage >( new CmdMailMsg(  ) );
 }
@@ -149,13 +149,13 @@ void SAL_CALL CmdMailSuppl::sendSimpleMailMessage( const Reference< XSimpleMailM
 {
     if ( ! xSimpleMailMessage.is() )
     {
-        throw ::com::sun::star::lang::IllegalArgumentException( "No message specified" ,
+        throw css::lang::IllegalArgumentException( "No message specified" ,
             static_cast < XSimpleMailClient * > (this), 1 );
     }
 
     if( ! m_xConfigurationProvider.is() )
     {
-        throw ::com::sun::star::uno::Exception( "Can not access configuration" ,
+        throw css::uno::Exception( "Can not access configuration" ,
             static_cast < XSimpleMailClient * > (this) );
     }
 
@@ -166,7 +166,7 @@ void SAL_CALL CmdMailSuppl::sendSimpleMailMessage( const Reference< XSimpleMailM
     OUString aProgram;
     if ( FileBase::E_None != FileBase::getSystemPathFromFileURL(aProgramURL, aProgram))
     {
-        throw ::com::sun::star::uno::Exception("Cound not convert executable path",
+        throw css::uno::Exception("Cound not convert executable path",
             static_cast < XSimpleMailClient * > (this));
     }
 
@@ -298,7 +298,7 @@ void SAL_CALL CmdMailSuppl::sendSimpleMailMessage( const Reference< XSimpleMailM
     FILE * f = popen(cmd.getStr(), "w");
     if (f == 0 || pclose(f) != 0)
     {
-        throw ::com::sun::star::uno::Exception("No mail client configured",
+        throw css::uno::Exception("No mail client configured",
             static_cast < XSimpleMailClient * > (this) );
     }
 }
diff --git a/shell/source/cmdmail/cmdmailsuppl.hxx b/shell/source/cmdmail/cmdmailsuppl.hxx
index 82f48d6..4d075d4 100644
--- a/shell/source/cmdmail/cmdmailsuppl.hxx
+++ b/shell/source/cmdmail/cmdmailsuppl.hxx
@@ -36,45 +36,45 @@
 
 class CmdMailSuppl :
     public  cppu::WeakImplHelper<
-        com::sun::star::system::XSimpleMailClientSupplier,
-        com::sun::star::system::XSimpleMailClient,
-        com::sun::star::lang::XServiceInfo >
+        css::system::XSimpleMailClientSupplier,
+        css::system::XSimpleMailClient,
+        css::lang::XServiceInfo >
 {
 
-    ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > m_xConfigurationProvider;
+    css::uno::Reference< css::lang::XMultiServiceFactory > m_xConfigurationProvider;
 
 public:
-    explicit CmdMailSuppl( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext );
+    explicit CmdMailSuppl( const css::uno::Reference< css::uno::XComponentContext >& xContext );
 
 
     // XSimpleMailClientSupplier
 
 
-    virtual ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailClient > SAL_CALL querySimpleMailClient(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Reference< css::system::XSimpleMailClient > SAL_CALL querySimpleMailClient(  )
+        throw (css::uno::RuntimeException, std::exception) override;
 
 
     // XSimpleMailClient
 
 
-    virtual ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailMessage > SAL_CALL createSimpleMailMessage(  )
-        throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Reference< css::system::XSimpleMailMessage > SAL_CALL createSimpleMailMessage(  )
+        throw (css::uno::RuntimeException, std::exception) override;
 
-    virtual void SAL_CALL sendSimpleMailMessage( const ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailMessage >& xSimpleMailMessage, sal_Int32 aFlag )
-        throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL sendSimpleMailMessage( const css::uno::Reference< css::system::XSimpleMailMessage >& xSimpleMailMessage, sal_Int32 aFlag )
+        throw (css::lang::IllegalArgumentException, css::uno::Exception, css::uno::RuntimeException, std::exception) override;
 
 
     // XServiceInfo
 
 
     virtual OUString SAL_CALL getImplementationName(  )
-        throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw(css::uno::RuntimeException, std::exception) override;
 
     virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
-        throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw(css::uno::RuntimeException, std::exception) override;
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
-        throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
+        throw(css::uno::RuntimeException, std::exception) override;
 };
 
 #endif
diff --git a/shell/source/unix/exec/shellexec.cxx b/shell/source/unix/exec/shellexec.cxx
index b7657cb..91da763 100644
--- a/shell/source/unix/exec/shellexec.cxx
+++ b/shell/source/unix/exec/shellexec.cxx
@@ -122,9 +122,8 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, const OUString& aPar
         // We need to re-encode file urls because osl_getFileURLFromSystemPath converts
         // to UTF-8 before encoding non ascii characters, which is not what other apps
         // expect.
-        OUString aURL(
-            com::sun::star::uri::ExternalUriReferenceTranslator::create(
-                m_xContext)->translateToExternal(aCommand));
+        OUString aURL = css::uri::ExternalUriReferenceTranslator::create(
+                            m_xContext)->translateToExternal(aCommand);
         if ( aURL.isEmpty() && !aCommand.isEmpty() )
         {
             throw RuntimeException(
@@ -160,13 +159,12 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, const OUString& aPar
 #else
         // The url launchers are expected to be in the $BRAND_BASE_DIR/LIBO_LIBEXEC_FOLDER
         // directory:
-        com::sun::star::uno::Reference< com::sun::star::util::XMacroExpander >
-            exp = com::sun::star::util::theMacroExpander::get(m_xContext);
+        css::uno::Reference< css::util::XMacroExpander > exp = css::util::theMacroExpander::get(m_xContext);
         OUString aProgramURL;
         try {
             aProgramURL = exp->expandMacros(
                 OUString( "$BRAND_BASE_DIR/" LIBO_LIBEXEC_FOLDER "/"));
-        } catch (com::sun::star::lang::IllegalArgumentException &)
+        } catch (css::lang::IllegalArgumentException &)
         {
             throw SystemShellExecuteException(
                 "Could not expand $BRAND_BASE_DIR path",
diff --git a/shell/source/unix/exec/shellexec.hxx b/shell/source/unix/exec/shellexec.hxx
index c32002a..bfcae18 100644
--- a/shell/source/unix/exec/shellexec.hxx
+++ b/shell/source/unix/exec/shellexec.hxx
@@ -32,34 +32,33 @@
 // class declaration
 
 
-class ShellExec : public ::cppu::WeakImplHelper< com::sun::star::system::XSystemShellExecute, com::sun::star::lang::XServiceInfo >
+class ShellExec : public ::cppu::WeakImplHelper< css::system::XSystemShellExecute, css::lang::XServiceInfo >
 {
-    OString m_aDesktopEnvironment;
-    ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >
-    m_xContext;
+    OString                                            m_aDesktopEnvironment;
+    css::uno::Reference< css::uno::XComponentContext > m_xContext;
 
 public:
-    explicit ShellExec(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext);
+    explicit ShellExec(const css::uno::Reference< css::uno::XComponentContext >& xContext);
 
 
     // XSystemShellExecute
 
 
     virtual void SAL_CALL execute( const OUString& aCommand, const OUString& aParameter, sal_Int32 nFlags )
-        throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::system::SystemShellExecuteException, ::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw (css::lang::IllegalArgumentException, css::system::SystemShellExecuteException, css::uno::RuntimeException, std::exception) override;
 
 
     // XServiceInfo
 
 
     virtual OUString SAL_CALL getImplementationName(  )
-        throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw(css::uno::RuntimeException, std::exception) override;
 
     virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
-        throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+        throw(css::uno::RuntimeException, std::exception) override;
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
-        throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
+        throw(css::uno::RuntimeException, std::exception) override;
 };
 
 
diff --git a/shell/source/win32/SysShExec.hxx b/shell/source/win32/SysShExec.hxx
index b3b6ad9..05c78fd 100644
--- a/shell/source/win32/SysShExec.hxx
+++ b/shell/source/win32/SysShExec.hxx
@@ -40,34 +40,33 @@ protected:
 class CSysShExec :
     public CSysShExecBase,
     public  cppu::WeakComponentImplHelper<
-            com::sun::star::system::XSystemShellExecute,
-            com::sun::star::lang::XServiceInfo >
+            css::system::XSystemShellExecute,
+            css::lang::XServiceInfo >
 {
-    ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >
-    m_xContext;
+    css::uno::Reference< css::uno::XComponentContext > m_xContext;
 
 public:
-    CSysShExec(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext);
+    CSysShExec(const css::uno::Reference< css::uno::XComponentContext >& xContext);
 
 
     // XSystemShellExecute
 
 
     virtual void SAL_CALL execute( const OUString& aCommand, const OUString& aParameter, sal_Int32 nFlags )
-        throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::system::SystemShellExecuteException, ::com::sun::star::uno::RuntimeException);
+        throw (css::lang::IllegalArgumentException, css::system::SystemShellExecuteException, css::uno::RuntimeException);
 
 
     // XServiceInfo
 
 
     virtual OUString SAL_CALL getImplementationName(  )
-        throw(::com::sun::star::uno::RuntimeException);
+        throw(css::uno::RuntimeException);
 
     virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
-        throw(::com::sun::star::uno::RuntimeException);
+        throw(css::uno::RuntimeException);
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
-        throw(::com::sun::star::uno::RuntimeException);
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
+        throw(css::uno::RuntimeException);
 };
 
 #endif
diff --git a/shell/source/win32/simplemail/smplmailclient.cxx b/shell/source/win32/simplemail/smplmailclient.cxx
index 359cc25..048d63a 100644
--- a/shell/source/win32/simplemail/smplmailclient.cxx
+++ b/shell/source/win32/simplemail/smplmailclient.cxx
@@ -171,7 +171,7 @@ Reference<XSimpleMailMessage> SAL_CALL CSmplMailClient::createSimpleMailMessage(
     [in|out] a buffer for the command line arguments. The buffer
     is assumed to be empty.
 
-    @throws com::sun::star::lang::IllegalArgumentException
+    @throws css::lang::IllegalArgumentException
     if an invalid file URL has been detected in the attachment list.
 */
 void CSmplMailClient::assembleCommandLine(
diff --git a/shell/source/win32/simplemail/smplmailmsg.hxx b/shell/source/win32/simplemail/smplmailmsg.hxx
index 0762bd8..f2a2895 100644
--- a/shell/source/win32/simplemail/smplmailmsg.hxx
+++ b/shell/source/win32/simplemail/smplmailmsg.hxx
@@ -29,74 +29,73 @@
 // class declaration
 
 
-class CSmplMailMsg :
-    public  cppu::WeakImplHelper< com::sun::star::system::XSimpleMailMessage2 >
+class CSmplMailMsg : public cppu::WeakImplHelper< css::system::XSimpleMailMessage2 >
 {
 public:
     CSmplMailMsg( );
 
     virtual void SAL_CALL setBody( const ::rtl::OUString& aBody )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
     virtual ::rtl::OUString SAL_CALL getBody(  )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
 
 
     virtual void SAL_CALL setRecipient( const OUString& aRecipient )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
     virtual OUString SAL_CALL getRecipient(  )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
 
 
-    virtual void SAL_CALL setCcRecipient( const ::com::sun::star::uno::Sequence< OUString >& aCcRecipient )
-        throw (::com::sun::star::uno::RuntimeException);
+    virtual void SAL_CALL setCcRecipient( const css::uno::Sequence< OUString >& aCcRecipient )
+        throw (css::uno::RuntimeException);
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getCcRecipient(  )
-        throw (::com::sun::star::uno::RuntimeException);
+    virtual css::uno::Sequence< OUString > SAL_CALL getCcRecipient(  )
+        throw (css::uno::RuntimeException);
 
 
 
-    virtual void SAL_CALL setBccRecipient( const ::com::sun::star::uno::Sequence< OUString >& aBccRecipient )
-        throw (::com::sun::star::uno::RuntimeException);
+    virtual void SAL_CALL setBccRecipient( const css::uno::Sequence< OUString >& aBccRecipient )
+        throw (css::uno::RuntimeException);
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getBccRecipient(  )
-        throw (::com::sun::star::uno::RuntimeException);
+    virtual css::uno::Sequence< OUString > SAL_CALL getBccRecipient(  )
+        throw (css::uno::RuntimeException);
 
 
 
     virtual void SAL_CALL setOriginator( const OUString& aOriginator )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
     virtual OUString SAL_CALL getOriginator(  )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
 
 
     virtual void SAL_CALL setSubject( const OUString& aSubject )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
     virtual OUString SAL_CALL getSubject(  )
-        throw (::com::sun::star::uno::RuntimeException);
+        throw (css::uno::RuntimeException);
 
 
 
-    virtual void SAL_CALL setAttachement( const ::com::sun::star::uno::Sequence< OUString >& aAttachement )
-        throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException);
+    virtual void SAL_CALL setAttachement( const css::uno::Sequence< OUString >& aAttachement )
+        throw (css::lang::IllegalArgumentException, css::uno::RuntimeException);
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getAttachement(  )
-        throw (::com::sun::star::uno::RuntimeException);
+    virtual css::uno::Sequence< OUString > SAL_CALL getAttachement(  )
+        throw (css::uno::RuntimeException);
 
 private:
-    OUString                                   m_aBody;
-    OUString                                   m_aRecipient;
-    OUString                                   m_aOriginator;
-    OUString                                   m_aSubject;
-    com::sun::star::uno::Sequence< OUString >  m_CcRecipients;
-    com::sun::star::uno::Sequence< OUString >  m_BccRecipients;
-    com::sun::star::uno::Sequence< OUString >  m_Attachements;
+    OUString                        m_aBody;
+    OUString                        m_aRecipient;
+    OUString                        m_aOriginator;
+    OUString                        m_aSubject;
+    css::uno::Sequence< OUString >  m_CcRecipients;
+    css::uno::Sequence< OUString >  m_BccRecipients;
+    css::uno::Sequence< OUString >  m_Attachements;
 };
 
 #endif
diff --git a/shell/source/win32/simplemail/smplmailsuppl.hxx b/shell/source/win32/simplemail/smplmailsuppl.hxx
index c5e1f68..4a280d8 100644
--- a/shell/source/win32/simplemail/smplmailsuppl.hxx
+++ b/shell/source/win32/simplemail/smplmailsuppl.hxx
@@ -37,26 +37,26 @@ protected:
 class CSmplMailSuppl :
     public CSmplMailSupplBase,
     public  cppu::WeakComponentImplHelper<
-            com::sun::star::system::XSimpleMailClientSupplier,
-            com::sun::star::lang::XServiceInfo >
+            css::system::XSimpleMailClientSupplier,
+            css::lang::XServiceInfo >
 {
 public:
     CSmplMailSuppl( );
     ~CSmplMailSuppl( );
 
     // XSimpleMailClientSupplier
-    virtual ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailClient > SAL_CALL querySimpleMailClient(  )
-        throw (::com::sun::star::uno::RuntimeException);
+    virtual css::uno::Reference< css::system::XSimpleMailClient > SAL_CALL querySimpleMailClient(  )
+        throw (css::uno::RuntimeException);
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName(  )
-        throw(::com::sun::star::uno::RuntimeException);
+        throw(css::uno::RuntimeException);
 
     virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
-        throw(::com::sun::star::uno::RuntimeException);
+        throw(css::uno::RuntimeException);
 
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
-        throw(::com::sun::star::uno::RuntimeException);
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames(  )
+        throw(css::uno::RuntimeException);
 };
 
 #endif


More information about the Libreoffice-commits mailing list
diff --git a/shell/source/sessioninstall/SyncDbusSessionHelper.hxx b/shell/source/sessioninstall/SyncDbusSessionHelper.hxx
index 3c2dc57..236f293 100644
--- a/shell/source/sessioninstall/SyncDbusSessionHelper.hxx
+++ b/shell/source/sessioninstall/SyncDbusSessionHelper.hxx
@@ -20,36 +20,36 @@ namespace shell { namespace sessioninstall
     class SyncDbusSessionHelper : public ::cppu::WeakImplHelper< ::org::freedesktop::PackageKit::XSyncDbusSessionHelper >
     {
         public:
-            SyncDbusSessionHelper(::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> const&);
+            SyncDbusSessionHelper(css::uno::Reference< css::uno::XComponentContext> const&);
             virtual ~SyncDbusSessionHelper() {}
 
             // XModify Methods
-            virtual void SAL_CALL InstallPackageFiles( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& files, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallPackageFiles( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& files, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallProvideFiles( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& files, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallProvideFiles( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& files, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallCatalogs( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& files, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallCatalogs( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& files, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallPackageNames( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& packages, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallPackageNames( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& packages, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallMimeTypes( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& mimeTypes, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallMimeTypes( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& mimeTypes, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallFontconfigResources( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& resources, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallFontconfigResources( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& resources, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallGStreamerResources( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& resources, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallGStreamerResources( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& resources, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* types */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) override
-                { throw ::com::sun::star::uno::RuntimeException(); } // not implemented
+            virtual void SAL_CALL InstallResources( ::sal_uInt32 /* xid */, const css::uno::Sequence< OUString >& /* types */, const css::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (css::uno::RuntimeException, std::exception) override
+                { throw css::uno::RuntimeException(); } // not implemented
 
-            virtual void SAL_CALL RemovePackageByFiles( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& files, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL RemovePackageByFiles( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& files, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL InstallPrinterDrivers( ::sal_uInt32 xid, const ::com::sun::star::uno::Sequence< OUString >& files, const OUString& interaction ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL InstallPrinterDrivers( ::sal_uInt32 xid, const css::uno::Sequence< OUString >& files, const OUString& interaction ) throw (css::uno::RuntimeException, std::exception) override;
 
             // XQuery Methods
-            virtual void SAL_CALL IsInstalled( const OUString& /* package_name */, const OUString& /* interaction */, sal_Bool& /* installed */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+            virtual void SAL_CALL IsInstalled( const OUString& /* package_name */, const OUString& /* interaction */, sal_Bool& /* installed */ ) throw (css::uno::RuntimeException, std::exception) override;
 
-            virtual void SAL_CALL SearchFile( const OUString& /* file_name */, const OUString& /* interaction */, sal_Bool& /* installed */, OUString& /* package_name */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) override
-                { throw ::com::sun::star::uno::RuntimeException(); } // not implemented
+            virtual void SAL_CALL SearchFile( const OUString& /* file_name */, const OUString& /* interaction */, sal_Bool& /* installed */, OUString& /* package_name */ ) throw (css::uno::RuntimeException, std::exception) override
+                { throw css::uno::RuntimeException(); } // not implemented
 
         private:
             SyncDbusSessionHelper( const SyncDbusSessionHelper& ) = delete;